﻿/* =========================================================================

InDesign ExtendScript

NAME: InBreakLinkToStyle.jsx
VERSION: 1.0

AUTHOR: Vitaly Batushev
DATE  : 11.05.2006

DESCRIPTION:
Если Вы назначите команде Break Link To Style "горячую клавишу" и попробуете
разорвать связь текста со стилем, то заодно потеряете и свое локальное форматирование –
тексту будет назначено нечто своеобразное.
Данный скрипт призван исправить эту досадную оплошность Adobe.
Скрипт назначает выделенным текстам стиль абзаца No Paragraph Style, а объектам – стиль None.

SUPPORT: http://toolbox.rudtp.ru
E-MAIL: toolbox@knews.polenet.ru

============================================================================ */

with (app) {
	// Проверяем количество открытых документов
	if (documents.length == 0) { exit(); }
	// Проверяем наличие выделения
	if (selection.length == 0) { exit(); }
	
	var mySel = selection[0];
	// Назначаем переменной myDoc ссылку на активный документ
	var myDoc = activeDocument;
	
	switch (mySel.constructor.name) {
		// Если выделено слово
		case 'Word':
			mySel.paragraphs[0].appliedParagraphStyle = myDoc.paragraphStyles[0];
			break;
		// Если выделен абзац
		case 'Paragraph':
			mySel.appliedParagraphStyle = myDoc.paragraphStyles[0];			
			break;
		// Если выделен текст (не обязательно весь, это может быть часть текста)
		case 'Text':
			mySel.appliedParagraphStyle = myDoc.paragraphStyles[0];
			break;
		// Если выделена текстовая колонка (при многоколоночной верстке)
		case 'TextColumn':
			mySel.appliedParagraphStyle = myDoc.paragraphStyles[0];
			break;
		// Если выделена ячейка, в том числе несколько ячеек или ряд/колонка в таблице
		case 'Cell':
			for (i = 0; i < mySel.cells.length; i++) {
				mySel.cells[i].texts[0].appliedParagraphStyle = myDoc.paragraphStyles[0];
			}
			break;
		// Если выделена таблица
		case 'Table':
			for (i = 0; i < mySel.cells.length; i++) {
				mySel.cells[i].texts[0].appliedParagraphStyle = myDoc.paragraphStyles[0];
			}
			break;
		// Если просто выставлен текстовый курсор
		case 'InsertionPoint':
			try { mySel.paragraphs[0].appliedParagraphStyle = myDoc.paragraphStyles[0]; }
			catch(e) { mySel.texts[0].appliedParagraphStyle = myDoc.paragraphStyles[0]; }
			break;
		// Если выделено что-то другое, пытаемся разорвать связь со стилем объекта
		default:
			try { mySel.appliedObjectStyle = myDoc.objectStyles[0]; }
			catch(e) { }
			break;
	}
}